@@ -1,9 +1,15 @@
-from pychess.Utils.const import *
+""" Knightodds variant """
+from pychess.Utils.const import KNIGHTODDSCHESS, VARIANTS_ODDS
 from pychess.Utils.Board import Board
 
 KNIGHTODDSSTART = "rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/R1BQKBNR w KQkq - 0 1"
 
+
 class KnightOddsBoard(Board):
+    """:Description: Knight Odds variant plays with the same rules as normal chess
+    but one side start the game with a knight missing
+    """
+
     variant = KNIGHTODDSCHESS
     __desc__ = _("One player starts with one less knight piece")
     name = _("Knight odds")
@@ -12,7 +18,7 @@ class KnightOddsBoard(Board):
     standard_rules = True
     variant_group = VARIANTS_ODDS
 
-    def __init__ (self, setup=False, lboard=None):
+    def __init__(self, setup=False, lboard=None):
         if setup is True:
             Board.__init__(self, setup=KNIGHTODDSSTART, lboard=lboard)
         else:
