@@ -13,8 +13,9 @@ from pychess.System.Log import log
 from pychess.System.prefix import getEngineDataPrefix
 from pychess.ic.icc import B_DTGR_END, B_UNIT_END
 
-if not hasattr(asyncio.StreamReader, 'readuntil'):
+if not hasattr(asyncio.StreamReader, "readuntil"):
     from pychess.System.readuntil import readuntil, _wait_for_data
+
     asyncio.StreamReader.readuntil = readuntil
     asyncio.StreamReader._wait_for_data = _wait_for_data
 
@@ -22,9 +23,9 @@ ENCODE = [ord(i) for i in "Timestamp (FICS) v1.0 - programmed by Henrik Gram."]
 ENCODELEN = len(ENCODE)
 G_RESPONSE = "\x029"
 FILLER = b"1234567890abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
-IAC_WONT_ECHO = b''.join([telnetlib.IAC, telnetlib.WONT, telnetlib.ECHO])
+IAC_WONT_ECHO = b"".join([telnetlib.IAC, telnetlib.WONT, telnetlib.ECHO])
 
-_DEFAULT_LIMIT = 2 ** 16
+_DEFAULT_LIMIT = 2**16
 
 
 class CanceledException(Exception):
@@ -37,8 +38,7 @@ class ICSStreamReader(asyncio.StreamReader):
         self.connected_event = connected_event
         self.name = name
 
-    @asyncio.coroutine
-    def read_until(self, *untils):
+    async def read_until(self, *untils):
         while True:
             for i, until in enumerate(untils):
                 start = self._buffer.find(bytearray(until, "ascii"))
@@ -46,15 +46,17 @@ class ICSStreamReader(asyncio.StreamReader):
                     self._buffer = self._buffer[start:]
                     return i
                 else:
-                    not_find = "read_until:%s , got:'%s'" % (until, self._buffer)
+                    not_find = f"read_until:{until} , got:'{self._buffer}'"
                     log.debug(not_find, extra={"task": (self.name, "raw")})
 
-            yield from self._wait_for_data('read_until')
+            await self._wait_for_data("read_until")
 
 
 class ICSStreamReaderProtocol(asyncio.StreamReaderProtocol):
     def __init__(self, stream_reader, client_connected_cb, loop, name, timeseal):
-        asyncio.StreamReaderProtocol.__init__(self, stream_reader, client_connected_cb=client_connected_cb, loop=loop)
+        asyncio.StreamReaderProtocol.__init__(
+            self, stream_reader, client_connected_cb=client_connected_cb, loop=loop
+        )
         self.name = name
         self.timeseal = timeseal
         self.connected = False
@@ -87,7 +89,9 @@ class ICSStreamReaderProtocol(asyncio.StreamReaderProtocol):
 
             if self.timeseal:
                 for i in range(g_count):
-                    self._stream_writer.write(self.encode(bytearray(G_RESPONSE, "utf-8")) + b"\n")
+                    self._stream_writer.write(
+                        self.encode(bytearray(G_RESPONSE, "utf-8")) + b"\n"
+                    )
         return data
 
     def encode(self, inbuf, timestamp=None):
@@ -95,7 +99,7 @@ class ICSStreamReaderProtocol(asyncio.StreamReaderProtocol):
 
         if not timestamp:
             timestamp = int(time.time() * 1000 % 1e7)
-        enc = inbuf + bytearray('\x18%d\x19' % timestamp, "ascii")
+        enc = inbuf + bytearray("\x18%d\x19" % timestamp, "ascii")
         padding = 12 - len(enc) % 12
         filler = random.sample(FILLER, padding)
         enc += bytearray(filler)
@@ -166,7 +170,7 @@ altpath = getEngineDataPrefix()
 timestamp_path = shutil.which(timestamp, os.X_OK, path=altpath)
 
 
-class ICSTelnet():
+class ICSTelnet:
     sensitive = False
 
     def __init__(self, timeseal):
@@ -179,8 +183,7 @@ class ICSTelnet():
         self.timeseal = timeseal
         self.ICC_buffer = ""
 
-    @asyncio.coroutine
-    def start(self, host, port, connected_event):
+    async def start(self, host, port, connected_event):
         if self.canceled:
             raise CanceledException()
         self.port = port
@@ -202,11 +205,18 @@ class ICSTelnet():
                         startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
                     else:
                         startupinfo = None
-                    create = asyncio.create_subprocess_exec(* ["%s" % timestamp_path, "-p", "%s" % self.port], startupinfo=startupinfo)
-                    self.timestamp_proc = yield from create
+                    create = asyncio.create_subprocess_exec(
+                        *["%s" % timestamp_path, "-p", "%s" % self.port],
+                        startupinfo=startupinfo,
+                    )
+                    self.timestamp_proc = await create
                     log.info("%s started OK" % timestamp_path)
                 except OSError as err:
-                    log.info("Can't start %s OSError: %s %s" % (timestamp_path, err.errno, err.strerror))
+                    log.info(
+                        "Can't start {} OSError: {} {}".format(
+                            timestamp_path, err.errno, err.strerror
+                        )
+                    )
                     self.port = port
                     self.host = host
             else:
@@ -219,10 +229,14 @@ class ICSTelnet():
             reader.connected_event.set()
 
         loop = asyncio.get_event_loop()
-        self.reader = ICSStreamReader(_DEFAULT_LIMIT, loop, self.connected_event, self.name)
-        self.protocol = ICSStreamReaderProtocol(self.reader, cb, loop, self.name, self.timeseal)
+        self.reader = ICSStreamReader(
+            _DEFAULT_LIMIT, loop, self.connected_event, self.name
+        )
+        self.protocol = ICSStreamReaderProtocol(
+            self.reader, cb, loop, self.name, self.timeseal
+        )
         coro = loop.create_connection(lambda: self.protocol, self.host, self.port)
-        self.transport, _protocol = yield from coro
+        self.transport, _protocol = await coro
         # writer = asyncio.StreamWriter(transport, protocol, reader, loop)
 
         if self.timeseal:
@@ -238,11 +252,11 @@ class ICSTelnet():
             self.transport.close()
 
     def get_init_string(self):
-        """ timeseal header: TIMESTAMP|bruce|Linux gruber 2.6.15-gentoo-r1 #9
-            PREEMPT Thu Feb 9 20:09:47 GMT 2006 i686 Intel(R) Celeron(R) CPU
-            2.00GHz GenuineIntel GNU/Linux| 93049 """
+        """timeseal header: TIMESTAMP|bruce|Linux gruber 2.6.15-gentoo-r1 #9
+        PREEMPT Thu Feb 9 20:09:47 GMT 2006 i686 Intel(R) Celeron(R) CPU
+        2.00GHz GenuineIntel GNU/Linux| 93049"""
         user = getpass.getuser()
-        uname = ' '.join(list(platform.uname()))
+        uname = " ".join(list(platform.uname()))
         return "TIMESTAMP|" + user + "|" + uname + "|"
 
     def write(self, string):
@@ -251,30 +265,30 @@ class ICSTelnet():
         log.info(logstr, extra={"task": (self.name, "raw")})
 
         if self.timeseal:
-            self.transport.write(self.protocol.encode(bytearray(string, "utf-8")) + b"\n")
+            self.transport.write(
+                self.protocol.encode(bytearray(string, "utf-8")) + b"\n"
+            )
         else:
             self.transport.write(string.encode() + b"\n")
 
-    @asyncio.coroutine
-    def readline(self):
+    async def readline(self):
         if self.canceled:
             raise CanceledException()
 
         if self.ICC:
-            line = yield from self.readuntil(b"\n")
+            line = await self.readuntil(b"\n")
             return line.strip()
         else:
-            line = yield from self.reader.readline()
+            line = await self.reader.readline()
             return line.decode("latin_1").strip()
 
-    @asyncio.coroutine
-    def readuntil(self, until):
+    async def readuntil(self, until):
         if self.canceled:
             raise CanceledException()
 
         if self.ICC:
             if len(self.ICC_buffer) == 0:
-                self.ICC_buffer = yield from self.reader.readuntil(until)
+                self.ICC_buffer = await self.reader.readuntil(until)
             i = self.ICC_buffer.find(until)
             m = sys.maxsize
             if i >= 0:
@@ -287,23 +301,22 @@ class ICSTelnet():
                 m = min(m, k)
             if m != sys.maxsize:
                 if m == i:
-                    stuff = self.ICC_buffer[:m + len(until)]
-                    self.ICC_buffer = self.ICC_buffer[m + len(until):]
+                    stuff = self.ICC_buffer[: m + len(until)]
+                    self.ICC_buffer = self.ICC_buffer[m + len(until) :]
                     return stuff.decode("latin_1")
                 else:
-                    stuff = self.ICC_buffer[:m + 2]
-                    self.ICC_buffer = self.ICC_buffer[m + 2:]
+                    stuff = self.ICC_buffer[: m + 2]
+                    self.ICC_buffer = self.ICC_buffer[m + 2 :]
                     return stuff.decode("latin_1")
             else:
                 return ""
         else:
-            data = yield from self.reader.readuntil(until)
+            data = await self.reader.readuntil(until)
             return data.decode("latin_1")
 
-    @asyncio.coroutine
-    def read_until(self, *untils):
+    async def read_until(self, *untils):
         if self.canceled:
             raise CanceledException()
 
-        ret = yield from self.reader.read_until(*untils)
+        ret = await self.reader.read_until(*untils)
         return ret
