@@ -1,53 +1,101 @@
 from gi.repository import Gtk
 
 from pychess import Variants
-from pychess.Utils.const import NORMALCHESS, ATOMICCHESS, BUGHOUSECHESS, CRAZYHOUSECHESS, \
-    LOSERSCHESS, SUICIDECHESS, FISCHERRANDOMCHESS, WILDCASTLESHUFFLECHESS, \
-    SHUFFLECHESS, RANDOMCHESS, ASYMMETRICRANDOMCHESS, WILDCASTLECHESS, UPSIDEDOWNCHESS, \
-    PAWNSPUSHEDCHESS, PAWNSPASSEDCHESS, GIVEAWAYCHESS, THREECHECKCHESS
+from pychess.Utils.const import (
+    NORMALCHESS,
+    ATOMICCHESS,
+    BUGHOUSECHESS,
+    CRAZYHOUSECHESS,
+    LOSERSCHESS,
+    SUICIDECHESS,
+    FISCHERRANDOMCHESS,
+    WILDCASTLESHUFFLECHESS,
+    SHUFFLECHESS,
+    RANDOMCHESS,
+    ASYMMETRICRANDOMCHESS,
+    WILDCASTLECHESS,
+    UPSIDEDOWNCHESS,
+    PAWNSPUSHEDCHESS,
+    PAWNSPASSEDCHESS,
+    GIVEAWAYCHESS,
+    THREECHECKCHESS,
+)
 
 IC_CONNECTED, IC_DISCONNECTED = range(2)
 
 # Fixed values of my relation to this game
 # http://www.freechess.org/Help/HelpFiles/style12.html
-IC_POS_INITIAL, IC_POS_ISOLATED, IC_POS_OBSERVING_EXAMINATION, IC_POS_OP_TO_MOVE, \
-    IC_POS_OBSERVING, IC_POS_ME_TO_MOVE, IC_POS_EXAMINATING = range(-4, 3)
+(
+    IC_POS_INITIAL,
+    IC_POS_ISOLATED,
+    IC_POS_OBSERVING_EXAMINATION,
+    IC_POS_OP_TO_MOVE,
+    IC_POS_OBSERVING,
+    IC_POS_ME_TO_MOVE,
+    IC_POS_EXAMINATING,
+) = range(-4, 3)
 
 # RatingType
-TYPE_BLITZ, TYPE_STANDARD, TYPE_LIGHTNING, TYPE_WILD, \
-    TYPE_BUGHOUSE, TYPE_CRAZYHOUSE, TYPE_SUICIDE, TYPE_LOSERS, TYPE_ATOMIC, \
-    TYPE_BULLET, TYPE_ONE_MINUTE, TYPE_THREE_MINUTE, TYPE_FIVE_MINUTE, \
-    TYPE_FIFTEEN_MINUTE, TYPE_FORTYFIVE_MINUTE, TYPE_CHESS960, \
-    TYPE_UNTIMED, TYPE_EXAMINED, TYPE_OTHER = range(19)
+(
+    TYPE_BLITZ,
+    TYPE_STANDARD,
+    TYPE_LIGHTNING,
+    TYPE_WILD,
+    TYPE_BUGHOUSE,
+    TYPE_CRAZYHOUSE,
+    TYPE_SUICIDE,
+    TYPE_LOSERS,
+    TYPE_ATOMIC,
+    TYPE_BULLET,
+    TYPE_ONE_MINUTE,
+    TYPE_THREE_MINUTE,
+    TYPE_FIVE_MINUTE,
+    TYPE_FIFTEEN_MINUTE,
+    TYPE_FORTYFIVE_MINUTE,
+    TYPE_CHESS960,
+    TYPE_UNTIMED,
+    TYPE_EXAMINED,
+    TYPE_OTHER,
+) = range(19)
 
-RATING_TYPES = (TYPE_BLITZ,
-                TYPE_STANDARD,
-                TYPE_LIGHTNING,
-                TYPE_BULLET,
-                TYPE_ONE_MINUTE,
-                TYPE_THREE_MINUTE,
-                TYPE_FIVE_MINUTE,
-                TYPE_FIFTEEN_MINUTE,
-                TYPE_FORTYFIVE_MINUTE,
-                TYPE_ATOMIC,
-                TYPE_BUGHOUSE,
-                TYPE_CRAZYHOUSE,
-                TYPE_LOSERS,
-                TYPE_SUICIDE,
-                TYPE_WILD,
-                TYPE_CHESS960,
-                TYPE_UNTIMED,
-                )
+RATING_TYPES = (
+    TYPE_BLITZ,
+    TYPE_STANDARD,
+    TYPE_LIGHTNING,
+    TYPE_BULLET,
+    TYPE_ONE_MINUTE,
+    TYPE_THREE_MINUTE,
+    TYPE_FIVE_MINUTE,
+    TYPE_FIFTEEN_MINUTE,
+    TYPE_FORTYFIVE_MINUTE,
+    TYPE_ATOMIC,
+    TYPE_BUGHOUSE,
+    TYPE_CRAZYHOUSE,
+    TYPE_LOSERS,
+    TYPE_SUICIDE,
+    TYPE_WILD,
+    TYPE_CHESS960,
+    TYPE_UNTIMED,
+)
 
 # Rating deviations
 DEVIATION_NONE, DEVIATION_ESTIMATED, DEVIATION_PROVISIONAL = range(3)
 
-IC_STATUS_PLAYING, IC_STATUS_ACTIVE, IC_STATUS_BUSY, IC_STATUS_OFFLINE, \
-    IC_STATUS_AVAILABLE, IC_STATUS_NOT_AVAILABLE, IC_STATUS_EXAMINING, \
-    IC_STATUS_IDLE, IC_STATUS_IN_TOURNAMENT, IC_STATUS_RUNNING_SIMUL_MATCH, \
-    IC_STATUS_UNKNOWN = range(11)
+(
+    IC_STATUS_PLAYING,
+    IC_STATUS_ACTIVE,
+    IC_STATUS_BUSY,
+    IC_STATUS_OFFLINE,
+    IC_STATUS_AVAILABLE,
+    IC_STATUS_NOT_AVAILABLE,
+    IC_STATUS_EXAMINING,
+    IC_STATUS_IDLE,
+    IC_STATUS_IN_TOURNAMENT,
+    IC_STATUS_RUNNING_SIMUL_MATCH,
+    IC_STATUS_UNKNOWN,
+) = range(11)
 
-TITLES_RE = "(?:\([A-Z*]+\))*"
+TITLES_RE = r"(?:\([A-Z*]+\))*"
 NAMES_RE = "[A-Za-z]+"
 
 DEVIATION = {
@@ -69,12 +117,14 @@ STATUS = {
 
 
 class GameType:
-    def __init__(self,
-                 fics_name,
-                 short_fics_name,
-                 rating_type,
-                 display_text=None,
-                 variant_type=NORMALCHESS):
+    def __init__(
+        self,
+        fics_name,
+        short_fics_name,
+        rating_type,
+        display_text=None,
+        variant_type=NORMALCHESS,
+    ):
         self.fics_name = fics_name
         self.short_fics_name = short_fics_name
         self.rating_type = rating_type
@@ -95,20 +145,16 @@ class GameType:
 
 class NormalGameType(GameType):
     def __init__(self, fics_name, short_fics_name, rating_type, display_text):
-        GameType.__init__(self,
-                          fics_name,
-                          short_fics_name,
-                          rating_type,
-                          display_text=display_text)
+        GameType.__init__(
+            self, fics_name, short_fics_name, rating_type, display_text=display_text
+        )
 
 
 class VariantGameType(GameType):
     def __init__(self, fics_name, short_fics_name, rating_type, variant_type):
-        GameType.__init__(self,
-                          fics_name,
-                          short_fics_name,
-                          rating_type,
-                          variant_type=variant_type)
+        GameType.__init__(
+            self, fics_name, short_fics_name, rating_type, variant_type=variant_type
+        )
 
     @property
     def display_text(self):
@@ -127,11 +173,9 @@ class WildGameType(VariantGameType):
     _instances = []
 
     def __init__(self, fics_name, variant_type):
-        VariantGameType.__init__(self,
-                                 fics_name,
-                                 "w",
-                                 TYPE_WILD,
-                                 variant_type=variant_type)
+        VariantGameType.__init__(
+            self, fics_name, "w", TYPE_WILD, variant_type=variant_type
+        )
         WildGameType._instances.append(self)
 
     @classmethod
@@ -148,19 +192,22 @@ GAME_TYPES = {
     "3-minute": NormalGameType("3-minute", "M", TYPE_THREE_MINUTE, _("3-minute")),
     "5-minute": NormalGameType("5-minute", "f", TYPE_FIVE_MINUTE, _("5-minute")),
     "15-minute": NormalGameType("15-minute", "F", TYPE_FIFTEEN_MINUTE, _("15-minute")),
-    "45-minute": NormalGameType("45-minute", "J", TYPE_FORTYFIVE_MINUTE, _("45-minute")),
+    "45-minute": NormalGameType(
+        "45-minute", "J", TYPE_FORTYFIVE_MINUTE, _("45-minute")
+    ),
     "chess960": NormalGameType("chess960", "K", TYPE_CHESS960, _("Chess960")),
     "untimed": NormalGameType("untimed", "u", TYPE_UNTIMED, _("Untimed")),
     "examined": NormalGameType("examined", "e", TYPE_EXAMINED, _("Examined")),
     "nonstandard": NormalGameType("nonstandard", "n", TYPE_OTHER, _("Other")),
     "w20": NormalGameType("loaded", "w20", TYPE_OTHER, _("Other")),  # loadfen/loadgame
-    "w21": NormalGameType("loaded", "w21", TYPE_OTHER, _("Other")),  # thematic tournaments
+    "w21": NormalGameType(
+        "loaded", "w21", TYPE_OTHER, _("Other")
+    ),  # thematic tournaments
     "atomic": VariantGameType("atomic", "x", TYPE_ATOMIC, ATOMICCHESS),
     "bughouse": VariantGameType("bughouse", "B", TYPE_BUGHOUSE, BUGHOUSECHESS),
     "crazyhouse": VariantGameType("crazyhouse", "z", TYPE_CRAZYHOUSE, CRAZYHOUSECHESS),
     "losers": VariantGameType("losers", "L", TYPE_LOSERS, LOSERSCHESS),
     "suicide": VariantGameType("suicide", "S", TYPE_SUICIDE, SUICIDECHESS),
-
     # FICS http://www.freechess.org/Help/HelpFiles/wild.html
     "wild/fr": WildGameType("wild/fr", FISCHERRANDOMCHESS),
     "wild/0": WildGameType("wild/0", WILDCASTLECHESS),
@@ -171,7 +218,6 @@ GAME_TYPES = {
     "wild/5": WildGameType("wild/5", UPSIDEDOWNCHESS),
     "wild/8": WildGameType("wild/8", PAWNSPUSHEDCHESS),
     "wild/8a": WildGameType("wild/8a", PAWNSPASSEDCHESS),
-
     # ICC https://www.chessclub.com/user/helpcenter/tips/wild.html
     "w17": WildGameType("w17", LOSERSCHESS),
     "w26": WildGameType("w26", GIVEAWAYCHESS),
@@ -203,25 +249,23 @@ for key in GAME_TYPES:
 # for the WildGameType's in GAME_TYPES above, and instead use
 # a dummy type for the all-encompassing "Wild" FICS rating for wild/* games
 GAME_TYPES_BY_SHORT_FICS_NAME = {
-    "w": GameType("wild",
-                  "w",
-                  TYPE_WILD,
-                  display_text=_("Wild"))
+    "w": GameType("wild", "w", TYPE_WILD, display_text=_("Wild"))
 }
 for key in GAME_TYPES:
     if not isinstance(GAME_TYPES[key], WildGameType):
-        GAME_TYPES_BY_SHORT_FICS_NAME[GAME_TYPES[key].short_fics_name] = \
-            GAME_TYPES[key]
+        GAME_TYPES_BY_SHORT_FICS_NAME[GAME_TYPES[key].short_fics_name] = GAME_TYPES[key]
 
 GAME_TYPES_BY_RATING_TYPE = {}
 for key in GAME_TYPES_BY_SHORT_FICS_NAME:
-    GAME_TYPES_BY_RATING_TYPE[GAME_TYPES_BY_SHORT_FICS_NAME[key].rating_type] = \
-        GAME_TYPES_BY_SHORT_FICS_NAME[key]
+    GAME_TYPES_BY_RATING_TYPE[
+        GAME_TYPES_BY_SHORT_FICS_NAME[key].rating_type
+    ] = GAME_TYPES_BY_SHORT_FICS_NAME[key]
 
 GAME_TYPES_BY_FICS_NAME = {}
 for key in GAME_TYPES_BY_SHORT_FICS_NAME:
-    GAME_TYPES_BY_FICS_NAME[GAME_TYPES_BY_SHORT_FICS_NAME[key].fics_name] = \
-        GAME_TYPES_BY_SHORT_FICS_NAME[key]
+    GAME_TYPES_BY_FICS_NAME[
+        GAME_TYPES_BY_SHORT_FICS_NAME[key].fics_name
+    ] = GAME_TYPES_BY_SHORT_FICS_NAME[key]
 
 
 # Finally add conflicting ICC game type
@@ -262,40 +306,75 @@ def time_control_to_gametype(minutes, gain):
         return GAME_TYPES["lightning"]
 
 
-TYPE_ADMINISTRATOR, TYPE_BLINDFOLD, TYPE_COMPUTER, \
-    TYPE_TEAM, TYPE_UNREGISTERED, TYPE_CHESS_ADVISOR, \
-    TYPE_SERVICE_REPRESENTATIVE, TYPE_TOURNAMENT_DIRECTOR, TYPE_MAMER_MANAGER, \
-    TYPE_GRAND_MASTER, TYPE_INTERNATIONAL_MASTER, TYPE_FIDE_MASTER, \
-    TYPE_WOMAN_GRAND_MASTER, TYPE_WOMAN_INTERNATIONAL_MASTER, TYPE_WOMAN_FIDE_MASTER,\
-    TYPE_DUMMY_ACCOUNT, TYPE_CANDIDATE_MASTER, TYPE_FIDE_ARBEITER, TYPE_NATIONAL_MASTER, \
-    TYPE_DISPLAY_MASTER = range(20)
+(
+    TYPE_ADMINISTRATOR,
+    TYPE_BLINDFOLD,
+    TYPE_COMPUTER,
+    TYPE_TEAM,
+    TYPE_UNREGISTERED,
+    TYPE_CHESS_ADVISOR,
+    TYPE_SERVICE_REPRESENTATIVE,
+    TYPE_TOURNAMENT_DIRECTOR,
+    TYPE_MAMER_MANAGER,
+    TYPE_GRAND_MASTER,
+    TYPE_INTERNATIONAL_MASTER,
+    TYPE_FIDE_MASTER,
+    TYPE_WOMAN_GRAND_MASTER,
+    TYPE_WOMAN_INTERNATIONAL_MASTER,
+    TYPE_WOMAN_FIDE_MASTER,
+    TYPE_DUMMY_ACCOUNT,
+    TYPE_CANDIDATE_MASTER,
+    TYPE_FIDE_ARBEITER,
+    TYPE_NATIONAL_MASTER,
+    TYPE_DISPLAY_MASTER,
+) = range(20)
 
-TITLE_TYPE_DISPLAY_TEXTS = (_("Administrator"),
-                            _("Blindfold Account"),
-                            _("Computer"),
-                            _("Team Account"),
-                            _("Unregistered"),
-                            _("Chess Advisor"),
-                            _("Service Representative"),
-                            _("Tournament Director"),
-                            _("Mamer Manager"),
-                            _("Grand Master"),
-                            _("International Master"),
-                            _("FIDE Master"),
-                            _("Woman Grand Master"),
-                            _("Woman International Master"),
-                            _("Woman FIDE Master"),
-                            _("Dummy Account"),
-                            _("Candidate Master"),
-                            _("FIDE Arbeiter"),
-                            _("National Master"),
-                            _("Display Master"),
-                            )
+TITLE_TYPE_DISPLAY_TEXTS = (
+    _("Administrator"),
+    _("Blindfold Account"),
+    _("Computer"),
+    _("Team Account"),
+    _("Unregistered"),
+    _("Chess Advisor"),
+    _("Service Representative"),
+    _("Tournament Director"),
+    _("Mamer Manager"),
+    _("Grand Master"),
+    _("International Master"),
+    _("FIDE Master"),
+    _("Woman Grand Master"),
+    _("Woman International Master"),
+    _("Woman FIDE Master"),
+    _("Dummy Account"),
+    _("Candidate Master"),
+    _("FIDE Arbeiter"),
+    _("National Master"),
+    _("Display Master"),
+)
 
 TITLE_TYPE_DISPLAY_TEXTS_SHORT = (
-    _("*"), _("B"), _("C"), _("T"), _("U"), _("CA"), _("SR"), _("TD"), _("TM"),
-    _("GM"), _("IM"), _("FM"), _("WGM"), _("WIM"), _("WFM"), _("D"), _("H"),
-    _("CM"), _("FA"), _("NM"), _("DM"))
+    _("*"),
+    _("B"),
+    _("C"),
+    _("T"),
+    _("U"),
+    _("CA"),
+    _("SR"),
+    _("TD"),
+    _("TM"),
+    _("GM"),
+    _("IM"),
+    _("FM"),
+    _("WGM"),
+    _("WIM"),
+    _("WFM"),
+    _("D"),
+    _("H"),
+    _("CM"),
+    _("FA"),
+    _("NM"),
+    _("DM"),
+)
 
 TITLES = {  # From FICS 'help who'
     "*": TYPE_ADMINISTRATOR,
@@ -363,10 +442,7 @@ def get_infobarmessage_content(player, text, gametype=None):
     return content
 
 
-def get_infobarmessage_content2(player,
-                                heading_text,
-                                message_text,
-                                gametype=None):
+def get_infobarmessage_content2(player, heading_text, message_text, gametype=None):
     hbox = Gtk.HBox()
     image = Gtk.Image()
     image.set_from_pixbuf(player.getIcon(size=24, gametype=gametype))
@@ -599,90 +675,522 @@ BLKCMD_ERROR_LENGTH = 520
 LIMIT_BLKCMD_ERRORS = 500
 
 FICS_COMMANDS = [
-    'abort', 'accept', 'addlist', 'adjourn', 'alias', 'allobservers', 'assess',
-    'backward', 'bell', 'best', 'boards', 'bsetup', 'bugwho', 'cbest',
-    'clearmessages', 'convert_bcf', 'convert_elo', 'convert_uscf', 'copygame',
-    'crank', 'cshout', 'date', 'decline', 'draw', 'examine', 'finger', 'flag',
-    'flip', 'fmessage', 'follow', 'forward', 'games', 'gnotify', 'goboard',
-    'handles', 'hbest', 'help', 'history', 'hrank', 'inchannel', 'index',
-    'info', 'it', 'jkill', 'jsave', 'kibitz', 'limits', 'llogons', 'logons',
-    'mailhelp', 'mailmess', 'mailmoves', 'mailoldmoves', 'mailsource',
-    'mailstored', 'match', 'messages', 'mexamine', 'moretime', 'moves', 'news',
-    'next', 'observe', 'oldmoves', 'open', 'password', 'pause', 'pending',
-    'pfollow', 'play', 'pobserve', 'promote', 'pstat', 'qtell', 'quit', 'rank',
-    'refresh', 'resign', 'resume', 'revert', 'say', 'seek', 'servers', 'set',
-    'shout', 'showlist', 'simabort', 'simallabort', 'simadjourn',
-    'simalladjourn', 'simgames', 'simmatch', 'simnext', 'simobserve',
-    'simopen', 'simpass', 'simprev', 'smoves', 'smposition', 'sought',
-    'sposition', 'statistics', 'stored', 'style', 'sublist', 'switch',
-    'takeback', 'tell', 'time', 'unalias', 'unexamine', 'unobserve', 'unpause',
-    'unseek', 'uptime', 'ustat', 'variables', 'whisper', 'who', 'withdraw',
-    'xkibitz', 'xtell', 'xwhisper', 'znotify']
+    "abort",
+    "accept",
+    "addlist",
+    "adjourn",
+    "alias",
+    "allobservers",
+    "assess",
+    "backward",
+    "bell",
+    "best",
+    "boards",
+    "bsetup",
+    "bugwho",
+    "cbest",
+    "clearmessages",
+    "convert_bcf",
+    "convert_elo",
+    "convert_uscf",
+    "copygame",
+    "crank",
+    "cshout",
+    "date",
+    "decline",
+    "draw",
+    "examine",
+    "finger",
+    "flag",
+    "flip",
+    "fmessage",
+    "follow",
+    "forward",
+    "games",
+    "gnotify",
+    "goboard",
+    "handles",
+    "hbest",
+    "help",
+    "history",
+    "hrank",
+    "inchannel",
+    "index",
+    "info",
+    "it",
+    "jkill",
+    "jsave",
+    "kibitz",
+    "limits",
+    "llogons",
+    "logons",
+    "mailhelp",
+    "mailmess",
+    "mailmoves",
+    "mailoldmoves",
+    "mailsource",
+    "mailstored",
+    "match",
+    "messages",
+    "mexamine",
+    "moretime",
+    "moves",
+    "news",
+    "next",
+    "observe",
+    "oldmoves",
+    "open",
+    "password",
+    "pause",
+    "pending",
+    "pfollow",
+    "play",
+    "pobserve",
+    "promote",
+    "pstat",
+    "qtell",
+    "quit",
+    "rank",
+    "refresh",
+    "resign",
+    "resume",
+    "revert",
+    "say",
+    "seek",
+    "servers",
+    "set",
+    "shout",
+    "showlist",
+    "simabort",
+    "simallabort",
+    "simadjourn",
+    "simalladjourn",
+    "simgames",
+    "simmatch",
+    "simnext",
+    "simobserve",
+    "simopen",
+    "simpass",
+    "simprev",
+    "smoves",
+    "smposition",
+    "sought",
+    "sposition",
+    "statistics",
+    "stored",
+    "style",
+    "sublist",
+    "switch",
+    "takeback",
+    "tell",
+    "time",
+    "unalias",
+    "unexamine",
+    "unobserve",
+    "unpause",
+    "unseek",
+    "uptime",
+    "ustat",
+    "variables",
+    "whisper",
+    "who",
+    "withdraw",
+    "xkibitz",
+    "xtell",
+    "xwhisper",
+    "znotify",
+]
 
 FICS_HELP = [
-    '_index', 'abort', 'abuse', 'academy', 'accept', 'addlist', 'addresses',
-    'adjourn', 'adjournments', 'adjudicate', 'adjudication', 'adm_app',
-    'adm_info', 'adm_new', 'admins', 'alias', 'allobservers', 'assess',
-    'atomic', 'audiochat', 'avail_vars', 'backward', 'bclock', 'bell', 'best',
-    'blind', 'blindfold', 'blindh', 'blitz', 'block_codes', 'bname', 'boards',
-    'brating', 'bsetup', 'bughouse', 'bughouse_strat', 'bugreport', 'bugwho',
-    'busy', 'ca', 'category', 'cbest', 'censor', 'chan_1', 'chan_4', 'channel',
-    'channel_list', 'channels', 'chess_adviser', 'chess_advisor',
-    'clearmessage', 'clearmessages', 'clock', 'clocks', 'clrsquare', 'cls',
-    'cls_info', 'command', 'commands', 'commit', 'computer_app',
-    'computer_list', 'computers', 'confidentiality', 'convert_bcf',
-    'convert_elo', 'convert_uscf', 'copygame', 'crank', 'crazyhouse',
-    'crazyhouse_strat', 'credit', 'crstat', 'cshout', 'csnewse', 'csnewsf',
-    'csnewsi', 'csnewsp', 'csnewst', 'date', 'decline', 'disclaimer',
-    'disconnection', 'draw', 'eco', 'eggo', 'email', 'etime', 'examine', 'exl',
-    'fen', 'fics_faq', 'fics_lingo', 'finger', 'flag', 'flip', 'fmessage',
-    'follow', 'formula', 'forward', 'fr', 'fr_rules', 'ftp_hints', 'games',
-    'games', 'getgame', 'getgi', 'getpi', 'ginfo', 'glicko', 'gnotify',
-    'goboard', 'handle', 'handles', 'hbest', 'help', 'highlight', 'history',
-    'hrank', 'hrstat', 'hstat', 'icsdrone', 'idlenotify', 'inchannel', 'index',
-    'indexfile', 'inetchesslib', 'info', 'intellegence', 'interfaces',
-    'intro_analysis', 'intro_basics', 'intro_general', 'intro_information',
-    'intro_moving', 'intro_playing', 'intro_settings', 'intro_talking',
-    'intro_welcome', 'irc_help', 'iset', 'it', 'iv_allresults', 'iv_atomic',
-    'iv_audiochat', 'iv_block', 'iv_boardinfo', 'iv_compressmove',
-    'iv_crazyhouse', 'iv_defprompt', 'iv_extascii', 'iv_extuserinfo', 'iv_fr',
-    'iv_gameinfo', 'iv_graph', 'iv_list', 'iv_lock', 'iv_pendinfo',
-    'iv_seekinfo', 'iv_seekremove', 'iv_startpos', 'ivariables', 'jkill',
-    'journal', 'jsave', 'kibitz', 'kiblevel', 'lag', 'lecture1', 'lessons',
-    'lightning', 'limits', 'links', 'lists', 'llogons', 'logons', 'losers',
-    'losers_chess', 'mailhelp', 'mailmess', 'mailmoves', 'mailoldmoves',
-    'mailstored', 'mamer', 'manual_usage', 'manual_vars', 'match',
-    'meeting_1_followup', 'meeting_1_long', 'meeting_1_short',
-    'meetings_index', 'messages', 'mexamine', 'moretime', 'motd', 'motd_fri',
-    'motd_help', 'motd_mon', 'motd_sat', 'motd_sun', 'motd_thu', 'motd_tue',
-    'motd_wed', 'moves', 'mule', 'new_features', 'newbie', 'news', 'next',
-    'noescape', 'noplay', 'notes', 'notify', 'observe', 'odds', 'oldmoves',
-    'oldpstat', 'open', 'partner', 'password', 'pause', 'pending', 'pfollow',
-    'pgn', 'ping', 'play', 'pobserve', 'powericsfaq', 'prefresh', 'primary',
-    'private', 'promote', 'pstat', 'ptell', 'ptime', 'qtell', 'quit', 'rank',
-    'rating_changes', 'ratings', 'rcopygame', 'rd', 'refresh', 'register',
-    'relay', 'relay_operator', 'rematch', 'replay', 'resign', 'result',
-    'resume', 'revert', 'rfollow', 'rmatch', 'robofics', 'robserve', 'rstat',
-    'sabort', 'say', 'sdraw', 'seek', 'servers', 'set', 'setup', 'shout',
-    'shout_quota', 'showadmins', 'showlist', 'showsrs', 'simabort',
-    'simadjourn', 'simallabort', 'simalladjourn', 'simgames', 'simmatch',
-    'simnext', 'simobserve', 'simopen', 'simpass', 'simprev', 'simuls',
-    'skype', 'smoves', 'smposition', 'sought', 'spending', 'sposition', 'sr',
-    'sr_info', 'standard', 'statistics', 'stats', 'stc', 'stored', 'style',
-    'style12', 'sublist', 'suicide_chess', 'summon', 'switch', 'system_alias',
-    'takeback', 'team', 'teamgames', 'tell', 'time', 'timeseal',
-    'timeseal_mac', 'timeseal_os2', 'timeseal_unix', 'timeseal_windows',
-    'timezones', 'tm', 'tomove', 'totals', 'totals_info', 'tournset',
-    'town_meetings', 'townmtg1', 'unalias', 'unexamine', 'unobserve',
-    'unpause', 'unseek', 'untimed', 'uptime', 'uscf', 'uscf_faq', 'ustat',
-    'v_autoflag', 'v_automail', 'v_availinfo', 'v_availmax', 'v_availmin',
-    'v_bell', 'v_bugopen', 'v_chanoff', 'v_cshout', 'v_ctell', 'v_echo',
-    'v_flip', 'v_formula', 'v_gin', 'v_height', 'v_highlight', 'v_inc',
-    'v_interface', 'v_jprivate', 'v_kibitz', 'v_kiblevel', 'v_language',
-    'v_mailmess', 'v_messreply', 'v_notakeback', 'v_notifiedby', 'v_open',
-    'v_pgn', 'v_pin', 'v_private', 'v_prompt', 'v_provshow', 'v_ptime',
-    'v_rated', 'v_ropen', 'v_seek', 'v_shout', 'v_silence', 'v_simopen',
-    'v_style', 'v_tell', 'v_time', 'v_tolerance', 'v_tourney', 'v_tzone',
-    'v_unobserve', 'v_width', 'variables', 'wclock', 'webpage', 'whenshut',
-    'whisper', 'who', 'wild', 'withdraw', 'wname', 'wrating', 'xkibitz',
-    'xtell', 'xwhisper', 'zhouse', 'znotify']
+    "_index",
+    "abort",
+    "abuse",
+    "academy",
+    "accept",
+    "addlist",
+    "addresses",
+    "adjourn",
+    "adjournments",
+    "adjudicate",
+    "adjudication",
+    "adm_app",
+    "adm_info",
+    "adm_new",
+    "admins",
+    "alias",
+    "allobservers",
+    "assess",
+    "atomic",
+    "audiochat",
+    "avail_vars",
+    "backward",
+    "bclock",
+    "bell",
+    "best",
+    "blind",
+    "blindfold",
+    "blindh",
+    "blitz",
+    "block_codes",
+    "bname",
+    "boards",
+    "brating",
+    "bsetup",
+    "bughouse",
+    "bughouse_strat",
+    "bugreport",
+    "bugwho",
+    "busy",
+    "ca",
+    "category",
+    "cbest",
+    "censor",
+    "chan_1",
+    "chan_4",
+    "channel",
+    "channel_list",
+    "channels",
+    "chess_adviser",
+    "chess_advisor",
+    "clearmessage",
+    "clearmessages",
+    "clock",
+    "clocks",
+    "clrsquare",
+    "cls",
+    "cls_info",
+    "command",
+    "commands",
+    "commit",
+    "computer_app",
+    "computer_list",
+    "computers",
+    "confidentiality",
+    "convert_bcf",
+    "convert_elo",
+    "convert_uscf",
+    "copygame",
+    "crank",
+    "crazyhouse",
+    "crazyhouse_strat",
+    "credit",
+    "crstat",
+    "cshout",
+    "csnewse",
+    "csnewsf",
+    "csnewsi",
+    "csnewsp",
+    "csnewst",
+    "date",
+    "decline",
+    "disclaimer",
+    "disconnection",
+    "draw",
+    "eco",
+    "eggo",
+    "email",
+    "etime",
+    "examine",
+    "exl",
+    "fen",
+    "fics_faq",
+    "fics_lingo",
+    "finger",
+    "flag",
+    "flip",
+    "fmessage",
+    "follow",
+    "formula",
+    "forward",
+    "fr",
+    "fr_rules",
+    "ftp_hints",
+    "games",
+    "games",
+    "getgame",
+    "getgi",
+    "getpi",
+    "ginfo",
+    "glicko",
+    "gnotify",
+    "goboard",
+    "handle",
+    "handles",
+    "hbest",
+    "help",
+    "highlight",
+    "history",
+    "hrank",
+    "hrstat",
+    "hstat",
+    "icsdrone",
+    "idlenotify",
+    "inchannel",
+    "index",
+    "indexfile",
+    "inetchesslib",
+    "info",
+    "intellegence",
+    "interfaces",
+    "intro_analysis",
+    "intro_basics",
+    "intro_general",
+    "intro_information",
+    "intro_moving",
+    "intro_playing",
+    "intro_settings",
+    "intro_talking",
+    "intro_welcome",
+    "irc_help",
+    "iset",
+    "it",
+    "iv_allresults",
+    "iv_atomic",
+    "iv_audiochat",
+    "iv_block",
+    "iv_boardinfo",
+    "iv_compressmove",
+    "iv_crazyhouse",
+    "iv_defprompt",
+    "iv_extascii",
+    "iv_extuserinfo",
+    "iv_fr",
+    "iv_gameinfo",
+    "iv_graph",
+    "iv_list",
+    "iv_lock",
+    "iv_pendinfo",
+    "iv_seekinfo",
+    "iv_seekremove",
+    "iv_startpos",
+    "ivariables",
+    "jkill",
+    "journal",
+    "jsave",
+    "kibitz",
+    "kiblevel",
+    "lag",
+    "lecture1",
+    "lessons",
+    "lightning",
+    "limits",
+    "links",
+    "lists",
+    "llogons",
+    "logons",
+    "losers",
+    "losers_chess",
+    "mailhelp",
+    "mailmess",
+    "mailmoves",
+    "mailoldmoves",
+    "mailstored",
+    "mamer",
+    "manual_usage",
+    "manual_vars",
+    "match",
+    "meeting_1_followup",
+    "meeting_1_long",
+    "meeting_1_short",
+    "meetings_index",
+    "messages",
+    "mexamine",
+    "moretime",
+    "motd",
+    "motd_fri",
+    "motd_help",
+    "motd_mon",
+    "motd_sat",
+    "motd_sun",
+    "motd_thu",
+    "motd_tue",
+    "motd_wed",
+    "moves",
+    "mule",
+    "new_features",
+    "newbie",
+    "news",
+    "next",
+    "noescape",
+    "noplay",
+    "notes",
+    "notify",
+    "observe",
+    "odds",
+    "oldmoves",
+    "oldpstat",
+    "open",
+    "partner",
+    "password",
+    "pause",
+    "pending",
+    "pfollow",
+    "pgn",
+    "ping",
+    "play",
+    "pobserve",
+    "powericsfaq",
+    "prefresh",
+    "primary",
+    "private",
+    "promote",
+    "pstat",
+    "ptell",
+    "ptime",
+    "qtell",
+    "quit",
+    "rank",
+    "rating_changes",
+    "ratings",
+    "rcopygame",
+    "rd",
+    "refresh",
+    "register",
+    "relay",
+    "relay_operator",
+    "rematch",
+    "replay",
+    "resign",
+    "result",
+    "resume",
+    "revert",
+    "rfollow",
+    "rmatch",
+    "robofics",
+    "robserve",
+    "rstat",
+    "sabort",
+    "say",
+    "sdraw",
+    "seek",
+    "servers",
+    "set",
+    "setup",
+    "shout",
+    "shout_quota",
+    "showadmins",
+    "showlist",
+    "showsrs",
+    "simabort",
+    "simadjourn",
+    "simallabort",
+    "simalladjourn",
+    "simgames",
+    "simmatch",
+    "simnext",
+    "simobserve",
+    "simopen",
+    "simpass",
+    "simprev",
+    "simuls",
+    "skype",
+    "smoves",
+    "smposition",
+    "sought",
+    "spending",
+    "sposition",
+    "sr",
+    "sr_info",
+    "standard",
+    "statistics",
+    "stats",
+    "stc",
+    "stored",
+    "style",
+    "style12",
+    "sublist",
+    "suicide_chess",
+    "summon",
+    "switch",
+    "system_alias",
+    "takeback",
+    "team",
+    "teamgames",
+    "tell",
+    "time",
+    "timeseal",
+    "timeseal_mac",
+    "timeseal_os2",
+    "timeseal_unix",
+    "timeseal_windows",
+    "timezones",
+    "tm",
+    "tomove",
+    "totals",
+    "totals_info",
+    "tournset",
+    "town_meetings",
+    "townmtg1",
+    "unalias",
+    "unexamine",
+    "unobserve",
+    "unpause",
+    "unseek",
+    "untimed",
+    "uptime",
+    "uscf",
+    "uscf_faq",
+    "ustat",
+    "v_autoflag",
+    "v_automail",
+    "v_availinfo",
+    "v_availmax",
+    "v_availmin",
+    "v_bell",
+    "v_bugopen",
+    "v_chanoff",
+    "v_cshout",
+    "v_ctell",
+    "v_echo",
+    "v_flip",
+    "v_formula",
+    "v_gin",
+    "v_height",
+    "v_highlight",
+    "v_inc",
+    "v_interface",
+    "v_jprivate",
+    "v_kibitz",
+    "v_kiblevel",
+    "v_language",
+    "v_mailmess",
+    "v_messreply",
+    "v_notakeback",
+    "v_notifiedby",
+    "v_open",
+    "v_pgn",
+    "v_pin",
+    "v_private",
+    "v_prompt",
+    "v_provshow",
+    "v_ptime",
+    "v_rated",
+    "v_ropen",
+    "v_seek",
+    "v_shout",
+    "v_silence",
+    "v_simopen",
+    "v_style",
+    "v_tell",
+    "v_time",
+    "v_tolerance",
+    "v_tourney",
+    "v_tzone",
+    "v_unobserve",
+    "v_width",
+    "variables",
+    "wclock",
+    "webpage",
+    "whenshut",
+    "whisper",
+    "who",
+    "wild",
+    "withdraw",
+    "wname",
+    "wrating",
+    "xkibitz",
+    "xtell",
+    "xwhisper",
+    "zhouse",
+    "znotify",
+]
